@@ -1102,6 +1102,7 @@ void AddMeSuccess(char *data, int len)
     (void)len; /* __UNUSED__ */
 
     hide_all_login_windows();
+    show_main_client();
     LOG(LOG_DEBUG, "common::AddMeSuccess", "addme_success received.");
     return;
 }
@@ -1482,6 +1483,8 @@ void StatsCmd(unsigned char *data, int len)
             case CS_STAT_WEIGHT_LIM:
                 set_weight_limit(cpl.stats.weight_limit = GetInt_String(data+i));
                 i += 4;
+                /* Mark weight limit changes to update the client inventory window */
+                cpl.ob->inv_updated = 1;
                 break;
 
             case CS_STAT_RANGE: {
