@@ -437,6 +437,7 @@ static void init_add_character_window() {
  * visible.
  */
 void choose_character_init() {
+    hide_main_client();
     gtk_widget_hide(login_window);
     gtk_widget_hide(add_character_window);
     gtk_widget_hide(create_account_window);
@@ -490,8 +491,6 @@ on_button_play_character_clicked(GtkButton *button, gpointer user_data) {
 
     if (gtk_tree_selection_get_selected(selected, &model, &iter)) {
         gtk_tree_model_get(model, &iter, CHAR_NAME, &name, -1);
-
-        hide_all_login_windows();
         play_character(name);
     }
 }
