@@ -20,8 +20,8 @@
 
 #ifdef HAVE_SDL
 
-#include <SDL.h>
-#include <SDL_image.h>
+#include <SDL/SDL.h>
+#include <SDL/SDL_image.h>
 #include <gtk/gtk.h>
 
 #ifndef WIN32
@@ -1023,6 +1023,9 @@ static void display_mapcell(int ax, int ay, int mx, int my)
  */
 void sdl_gen_map(int redraw) {
     int x, y, num_spaces = 0, num_drawn = 0;
+    if (redrawbitmap == NULL) {
+        return;
+    }
     update_redrawbitmap();
 
     for( x= 0; x<use_config[CONFIG_MAPWIDTH]; x++) {
